==> magento-module-data-services-multishipping-7.3.3.zip: ViewModel/Checkout/MultishippingSuccessContextProvider.php <==
<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
declare(strict_types=1);

namespace Magento\DataServicesMultishipping\ViewModel\Checkout;

use Magento\Customer\Model\Session as CustomerSession;
use Magento\Framework\Serialize\Serializer\Json;
use Magento\Framework\View\Element\Block\ArgumentInterface;
use Magento\Multishipping\Model\Checkout\Type\Multishipping;
use Magento\Sales\Api\OrderRepositoryInterface;

/**
 * ViewModel for Multishipping Checkout Success Context
 */
class MultishippingSuccessContextProvider implements ArgumentInterface
{
    /**
     * @param Multishipping $multishipping
     * @param CustomerSession $customerSession
     * @param OrderRepositoryInterface $orderRepository
     * @param Json $jsonSerializer
     */
    public function __construct(
        private Multishipping $multishipping,
        private CustomerSession $customerSession,
        private OrderRepositoryInterface $orderRepository,
        private Json $jsonSerializer
    ) {
    }

    /**
     * Return cart id for event tracking
     *
     * @return int
     */
    public function getCartId(): int
    {
        $cartId = $this->customerSession->getDataServicesCartId();
        $this->customerSession->unsDataServicesCartId();
        return $cartId;
    }

    /**
     * Return customer email for event tracking
     *
     * @return string
     */
    public function getCustomerEmail(): string
    {
        return $this->customerSession->getCustomer()->getEmail();
    }

    /**
     * Return order ids for event tracking
     *
     * @return string
     */
    public function getOrderId(): string
    {
        return implode(',', $this->multishipping->getOrderIds());
    }

    /**
     * Return order subtotal rounded to 2 decimals
     * 
     * @param \Magento\Sales\Api\Data\OrderInterface $order
     * @return float
     */
    private function getOrderSubTotal($order): float
    {
        return round((float)$order->getSubTotal(), 2);
    }

    /**
     * Return payment method data.
     * Tmp. return data only for the latest order
     *
     * @return string
     */
    public function getPayment(): string
    {
        $paymentData = [];
        foreach ($this->multishipping->getOrderIds() as $orderId) {
            $order = $this->orderRepository->get($orderId);
            $payment = $order->getPayment();
            $paymentData[] = [
                'total' => $this->getOrderSubTotal($order),
                'paymentMethodCode' => $payment->getMethod(),
                'paymentMethodName' => $payment->getMethodInstance()->getTitle(),
                'orderId' => $orderId,
            ];
        }
        return $this->jsonSerializer->serialize($paymentData);
    }

    /**
     * Return shipping data
     * Tmp. return data only for the latest order
     *
     * @return string
     */
    public function getShipping(): string
    {
        $shippingData = [];
        foreach ($this->multishipping->getOrderIds() as $orderId) {
            $order = $this->orderRepository->get($orderId);
            $shippingData[$orderId] =
                [
                    'shippingMethod' => $order->getShippingMethod(),
                    'shippingAmount' => $order->getShippingAmount(),
                ];
        }
        return $this->jsonSerializer->serialize($shippingData);
    }
}

==> magento-module-data-services-multishipping-7.4.0.zip: ViewModel/Checkout/MultishippingSuccessContextProvider.php <==
<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
declare(strict_types=1);

namespace Magento\DataServicesMultishipping\ViewModel\Checkout;

use Magento\Customer\Model\Session as CustomerSession;
use Magento\Framework\Serialize\Serializer\Json;
use Magento\Framework\View\Element\Block\ArgumentInterface;
use Magento\Multishipping\Model\Checkout\Type\Multishipping;
use Magento\Sales\Api\OrderRepositoryInterface;

/**
 * ViewModel for Multishipping Checkout Success Context
 */
class MultishippingSuccessContextProvider implements ArgumentInterface
{
    /**
     * @param Multishipping $multishipping
     * @param CustomerSession $customerSession
     * @param OrderRepositoryInterface $orderRepository
     * @param Json $jsonSerializer
     */
    public function __construct(
        private Multishipping $multishipping,
        private CustomerSession $customerSession,
        private OrderRepositoryInterface $orderRepository,
        private Json $jsonSerializer
    ) {
    }

    /**
     * Return cart id for event tracking
     *
     * @return int
     */
    public function getCartId(): int
    {
        $cartId = $this->customerSession->getDataServicesCartId();
        $this->customerSession->unsDataServicesCartId();
        return $cartId;
    }

    /**
     * Return customer email for event tracking
     *
     * @return string
     */
    public function getCustomerEmail(): string
    {
        return $this->customerSession->getCustomer()->getEmail();
    }

    /**
     * Return order ids for event tracking
     *
     * @return string
     */
    public function getOrderId(): string
    {
        return implode(',', $this->multishipping->getOrderIds());
    }

    /**
     * Return order subtotal rounded to 2 decimals
     * 
     * @param \Magento\Sales\Api\Data\OrderInterface $order
     * @return float
     */
    private function getOrderSubTotal($order): float
    {
        return round((float)$order->getSubTotal(), 2);
    }

    /**
     * Return payment method data.
     * Tmp. return data only for the latest order
     *
     * @return string
     */
    public function getPayment(): string
    {
        $paymentData = [];
        foreach ($this->multishipping->getOrderIds() as $orderId) {
            $order = $this->orderRepository->get($orderId);
            $payment = $order->getPayment();
            $paymentData[] = [
                'total' => $this->getOrderSubTotal($order),
                'paymentMethodCode' => $payment->getMethod(),
                'paymentMethodName' => $payment->getMethodInstance()->getTitle(),
                'orderId' => $orderId,
            ];
        }
        return $this->jsonSerializer->serialize($paymentData);
    }

    /**
     * Return shipping data
     *
     * @return string
     */
    public function getShipping(): string
    {
        $shippingData = [];
        foreach ($this->multishipping->getOrderIds() as $orderId) {
            $order = $this->orderRepository->get($orderId);
            $shippingData[$orderId] =
                [
                    'shippingMethod' => $order->getShippingMethod(),
                    'shippingAmount' => $order->getShippingAmount(),
                ];
        }
        return $this->jsonSerializer->serialize($shippingData);
    }

    /**
     * Return discount amount
     * Currently going to return the sum of all discounts
     * In future if multiple events are sent per order, this should be changed to return the discount for each order
     * @return float
     */
    public function getDiscountAmount(): float
    {
        $discountData = 0;
        foreach ($this->multishipping->getOrderIds() as $orderId) {
            $order = $this->orderRepository->get($orderId);
            $discountData += $order->getDiscountAmount();
        }
        return $discountData;
    }
}
